==> keyclic_sdk_api-2.1.0.tar.gz: lib/model/feedback_links_self_iri_template.dart <==
part of keyclic_sdk_api.api;

class FeedbackLinksSelfIriTemplate {
  FeedbackLinksSelfIriTemplate({
    this.mapping,
  });

  FeedbackLinksSelfIriTemplate.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    mapping =
        ContributionLinksFeedbackIriTemplateMapping.fromJson(json['mapping']);
  }

  ContributionLinksFeedbackIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is FeedbackLinksSelfIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<FeedbackLinksSelfIriTemplate> listFromJson(List<dynamic> json) {
    return json == null
        ? <FeedbackLinksSelfIriTemplate>[]
        : json
            .map(
                (dynamic value) => FeedbackLinksSelfIriTemplate.fromJson(value))
            .toList();
  }

  static Map<String, FeedbackLinksSelfIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, FeedbackLinksSelfIriTemplate>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = FeedbackLinksSelfIriTemplate.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'mapping': mapping,
    };
  }

  @override
  String toString() {
    return 'FeedbackLinksSelfIriTemplate[mapping=$mapping, ]';
  }
}

==> keyclic_sdk_api-2.2.12.tar.gz: lib/model/feedback_links_self_iri_template.dart <==
part of keyclic_sdk_api.api;

class FeedbackLinksSelfIriTemplate {
  FeedbackLinksSelfIriTemplate({
    this.mapping,
  });

  factory FeedbackLinksSelfIriTemplate.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return FeedbackLinksSelfIriTemplate(
      mapping:
          ContributionLinksFeedbackIriTemplateMapping.fromJson(json['mapping']),
    );
  }

  ContributionLinksFeedbackIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is FeedbackLinksSelfIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<FeedbackLinksSelfIriTemplate> listFromJson(List<dynamic> json) {
    return json == null
        ? <FeedbackLinksSelfIriTemplate>[]
        : json
            .map(
                (dynamic value) => FeedbackLinksSelfIriTemplate.fromJson(value))
            .toList();
  }

  static Map<String, FeedbackLinksSelfIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, FeedbackLinksSelfIriTemplate>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = FeedbackLinksSelfIriTemplate.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping,
    };
  }

  @override
  String toString() {
    return 'FeedbackLinksSelfIriTemplate[mapping=$mapping, ]';
  }
}
